{
	"name" : "EZ Publish eCommerce Interface",
	"version" : "1.0",
	"author" : "Tiny",
	"category" : "Interfaces/CMS & eCommerce",
	"website" : "http://tinyerp.com/demo02_6.html",
	"description": "Module to interface with the EZ Publish ecommerce system.",
	"depends" : ["product", "stock", "sale"],
	"init_xml" : [],
	"demo_xml" : ["esale_demo.xml"],
	"update_xml" : ["esale_view.xml"],
	"active": False,
	"installable": False
}
